@@ -50,7 +50,9 @@ class Application : public QObject
 
 public:
     /** Constructs a new Konsole application. */
-    Application(QCommandLineParser &parser);
+    explicit Application(QSharedPointer<QCommandLineParser> parser);
+
+    static void populateCommandLineParser(QCommandLineParser *parser);
 
     ~Application();
 
@@ -71,7 +73,7 @@ private slots:
     void toggleBackgroundInstance();
 
 public slots:
-    void slotActivateRequested (const QStringList &args, const QString &workingDir);
+    void slotActivateRequested (QStringList args, const QString &workingDir);
 
 private:
     void listAvailableProfiles();
@@ -86,7 +88,7 @@ private:
     void finalizeNewMainWindow(MainWindow* window);
 
     MainWindow* _backgroundInstance;
-    QCommandLineParser &m_parser;
+    QSharedPointer<QCommandLineParser> m_parser;
 };
 }
 #endif  // APPLICATION_H
