@@ -10,7 +10,7 @@ done
 $EXTRACTRC `find . -name \*.ui`          >>  rc.cpp
 $EXTRACTRC `find . -name \*.kcfg` >> rc.cpp
 $EXTRACTRC `find ../desktop -name \*.rc` >> rc.cpp
-$XGETTEXT *.cpp -o $podir/konsole.pot
+$XGETTEXT `find . -name \*.cpp -o -name \*.h` -o $podir/konsole.pot
 rm -f schemas.cpp
 #rm -f tips.cpp
 rm -f rc.cpp
