@@ -179,21 +179,6 @@ public:
         return _tripleClickMode;
     }
 
-    /**
-     * Specifies whether links and email addresses should be underlined when
-     * hovered by the mouse. Defaults to true.
-     */
-    void setUnderlineLinks(bool value) {
-        _underlineLinks = value;
-    }
-    /**
-     * Returns true if links and email addresses should be underlined when
-     * hovered by the mouse.
-     */
-    bool getUnderlineLinks() const {
-        return _underlineLinks;
-    }
-
     /**
      * Specifies whether links and email addresses should be opened when
      * clicked with the mouse. Defaults to false.
@@ -461,17 +446,11 @@ public:
     }
 
     /**
-     * Enables or disables showing hints on URLs when ctrl is pressed
+     * Sets the modifiers that shows URL hints when they are pressed
      * Defaults to disabled.
      */
-    void setEnableUrlHints(bool on) {
-        _enableShowUrlHint = on;
-    }
-    /**
-     * Returns the status of the BiDi rendering in this widget.
-     */
-    bool areUrlHintsEnabled() const {
-        return _enableShowUrlHint;
+    void setUrlHintsModifiers(int modifiers) {
+        _urlHintsModifiers = Qt::KeyboardModifiers(modifiers);
     }
 
     /**
@@ -887,9 +866,8 @@ private:
     QTimer* _blinkTextTimer;
     QTimer* _blinkCursorTimer;
 
+    Qt::KeyboardModifiers _urlHintsModifiers;
     bool _showUrlHint;
-    bool _enableShowUrlHint;
-    bool _underlineLinks;     // Underline URL and hosts on mouse hover
     bool _openLinksByDirectClick;     // Open URL and hosts by single mouse click
 
     bool _ctrlRequiredForDrag; // require Ctrl key for drag selected text
