@@ -155,7 +155,7 @@ void ViewManager::setupActions()
 
         QAction* closeActiveAction = new QAction(i18nc("@action:inmenu Close Active View", "Close Active") , this);
         closeActiveAction->setIcon(QIcon::fromTheme(QStringLiteral("view-close")));
-        collection->setDefaultShortcut(closeActiveAction, Qt::CTRL + Qt::SHIFT + Qt::Key_S);
+        collection->setDefaultShortcut(closeActiveAction, Qt::CTRL + Qt::SHIFT + Qt::Key_X);
         closeActiveAction->setEnabled(false);
         collection->addAction("close-active-view", closeActiveAction);
         connect(closeActiveAction , &QAction::triggered , this , &Konsole::ViewManager::closeActiveContainer);
@@ -720,8 +720,8 @@ void ViewManager::viewDestroyed(QWidget* view)
 {
     // Note: the received QWidget has already been destroyed, so
     // using dynamic_cast<> or qobject_cast<> does not work here
-    TerminalDisplay* display = static_cast<TerminalDisplay*>(view);
-    Q_ASSERT(display);
+    // We only need the pointer address to look it up below
+    TerminalDisplay* display = reinterpret_cast<TerminalDisplay*>(view);
 
     // 1. detach view from session
     // 2. if the session has no views left, close it
@@ -804,7 +804,6 @@ void ViewManager::applyProfileToView(TerminalDisplay* view , const Profile::Ptr
     view->setTripleClickMode(Enum::TripleClickModeEnum(tripleClickMode));
 
     view->setAutoCopySelectedText(profile->autoCopySelectedText());
-    view->setUnderlineLinks(profile->underlineLinksEnabled());
     view->setControlDrag(profile->property<bool>(Profile::CtrlRequiredForDrag));
     view->setDropUrlsAsText(profile->property<bool>(Profile::DropUrlsAsText));
     view->setBidiEnabled(profile->bidiRenderingEnabled());
@@ -813,7 +812,7 @@ void ViewManager::applyProfileToView(TerminalDisplay* view , const Profile::Ptr
 
     view->setOpenLinksByDirectClick(profile->property<bool>(Profile::OpenLinksByDirectClickEnabled));
 
-    view->setEnableUrlHints(profile->property<bool>(Profile::EnableUrlHints));
+    view->setUrlHintsModifiers(profile->property<int>(Profile::UrlHintsModifiers));
 
     int middleClickPasteMode = profile->property<int>(Profile::MiddleClickPasteMode);
     if (middleClickPasteMode == Enum::PasteFromX11Selection)
@@ -821,9 +820,9 @@ void ViewManager::applyProfileToView(TerminalDisplay* view , const Profile::Ptr
     else if (middleClickPasteMode == Enum::PasteFromClipboard)
         view->setMiddleClickPasteMode(Enum::PasteFromClipboard);
 
-    // margin/center - these are hard-fixed ATM
-    view->setMargin(1);
-    view->setCenterContents(false);
+    // margin/center
+    view->setMargin(profile->property<int>(Profile::TerminalMargin));
+    view->setCenterContents(profile->property<bool>(Profile::TerminalCenter));
 
     // cursor shape
     int cursorShape = profile->property<int>(Profile::CursorShape);
@@ -901,7 +900,7 @@ void ViewManager::saveSessions(KConfigGroup& group)
 {
     // find all unique session restore IDs
     QList<int> ids;
-    QHash<Session*, int> unique;
+    QSet<Session*> unique;
 
     // first: sessions in the active container, preserving the order
     ViewContainer* container = _viewSplitter->activeContainer();
@@ -915,8 +914,10 @@ void ViewManager::saveSessions(KConfigGroup& group)
         Q_ASSERT(view);
         Session* session = _sessionMap[view];
         ids << SessionManager::instance()->getRestoreId(session);
-        if (view == activeview) group.writeEntry("Active", tab);
-        unique.insert(session, 1);
+        unique.insert(session);
+        if (view == activeview) {
+            group.writeEntry("Active", tab);
+        }
         tab++;
     }
 
@@ -925,7 +926,7 @@ void ViewManager::saveSessions(KConfigGroup& group)
     foreach(Session * session, _sessionMap) {
         if (!unique.contains(session)) {
             ids << SessionManager::instance()->getRestoreId(session);
-            unique.insert(session, 1);
+            unique.insert(session);
         }
     }
 
