@@ -21,6 +21,7 @@
 #include "Application.h"
 #include "MainWindow.h"
 #include "config-konsole.h"
+#include "KonsoleSettings.h"
 
 // OS specific
 #include <qplatformdefs.h>
@@ -41,9 +42,6 @@ using Konsole::Application;
 // fill the KAboutData structure with information about contributors to Konsole.
 void fillAboutData(KAboutData& aboutData);
 
-// fill the KCmdLineOptions object with konsole specific options.
-void fillCommandLineOptions(QCommandLineParser &parser);
-
 // check and report whether this konsole instance should use a new konsole
 // process, or re-use an existing konsole process.
 bool shouldUseNewProcess(int argc, char *argv[]);
@@ -109,15 +107,20 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
 
     KCrash::initialize();
 
-    QCommandLineParser parser;
-    parser.setApplicationDescription(about.shortDescription());
-    parser.addHelpOption();
-    parser.addVersionOption();
-    fillCommandLineOptions(parser);
-    about.setupCommandLine(&parser);
+    QSharedPointer<QCommandLineParser> parser(new QCommandLineParser);
+    parser->setApplicationDescription(about.shortDescription());
+    parser->addHelpOption();
+    parser->addVersionOption();
+    about.setupCommandLine(parser.data());
+    Application::populateCommandLineParser(parser.data());
 
-    parser.process(*app);
-    about.processCommandLine(&parser);
+    parser->process(*app);
+    about.processCommandLine(parser.data());
+
+    // Enable user to force multiple instances
+    if (!Konsole::KonsoleSettings::useSingleInstance()) {
+        startupOption = KDBusService::Multiple;
+    }
 
     atexit(deleteQApplication);
     // Ensure that we only launch a new instance if we need to
@@ -248,70 +251,6 @@ bool shouldUseNewProcess(int argc, char *argv[])
     return hasControllingTTY;
 }
 
-void fillCommandLineOptions(QCommandLineParser &parser)
-{
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("profile"),
-                                        i18nc("@info:shell", "Name of profile to use for new Konsole instance"),
-                                        QStringLiteral("name")));
-    parser.addOption(QCommandLineOption(QStringList(QStringLiteral("fallback-profile")),
-                                        i18nc("@info:shell", "Use the internal FALLBACK profile")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("workdir"),
-                                        i18nc("@info:shell", "Set the initial working directory of the new tab or"
-                                              " window to 'dir'"),
-                                        QStringLiteral("dir")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("hold") << QStringLiteral("noclose"),
-                                        i18nc("@info:shell", "Do not close the initial session automatically when it"
-                                        " ends.")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("new-tab"),
-                                        i18nc("@info:shell", "Create a new tab in an existing window rather than"
-                                              " creating a new window")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("tabs-from-file"),
-                                        i18nc("@info:shell", "Create tabs as specified in given tabs configuration"
-                                        " file"),
-                                        QStringLiteral("file")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("background-mode"),
-                                        i18nc("@info:shell", "Start Konsole in the background and bring to the front"
-                                              " when Ctrl+Shift+F12 (by default) is pressed")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("separate"), i18n("Run in a separate process")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("show-menubar"), i18nc("@info:shell", "Show the menubar, overriding the default setting")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("hide-menubar"), i18nc("@info:shell", "Hide the menubar, overriding the default setting")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("show-tabbar"), i18nc("@info:shell", "Show the tabbar, overriding the default setting")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("hide-tabbar"), i18nc("@info:shell", "Hide the tabbar, overriding the default setting")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("fullscreen"), i18nc("@info:shell", "Start Konsole in fullscreen mode")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("notransparency"),
-                                        i18nc("@info:shell", "Disable transparent backgrounds, even if the system"
-                                              " supports them.")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("list-profiles"),
-                                        i18nc("@info:shell", "List the available profiles")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("list-profile-properties"),
-                                        i18nc("@info:shell", "List all the profile properties names and their type"
-                                              " (for use with -p)")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("p"),
-                                        i18nc("@info:shell", "Change the value of a profile property."),
-                                        QStringLiteral("property=value")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("e"),
-                                        i18nc("@info:shell", "Command to execute. This option will catch all following"
-                                              " arguments, so use it as the last option."),
-                                        QStringLiteral("cmd")));
-    parser.addPositionalArgument(QStringLiteral("[args]"),
-                                 i18nc("@info:shell", "Arguments passed to command"));
-
-    // Add a no-op compatibility option to make Konsole compatible with
-    // Debian's policy on X terminal emulators.
-    // -T is technically meant to set a title, that is not really meaningful
-    // for Konsole as we have multiple user-facing options controlling
-    // the title and overriding whatever is set elsewhere.
-    // https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=532029
-    // https://www.debian.org/doc/debian-policy/ch-customized-programs.html#s11.8.3
-    auto titleOption = QCommandLineOption(QStringList() << QStringLiteral("T"),
-                                          QStringLiteral("Debian policy compatibility, not used"),
-                                          QStringLiteral("value"));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-    titleOption.setHidden(true);
-#endif
-    parser.addOption(titleOption);
-}
-
 void fillAboutData(KAboutData& aboutData)
 {
     aboutData.setProgramIconName(QStringLiteral("utilities-terminal"));
